@@ -37,7 +37,7 @@ class ToolMirrorReprepro(ToolShell):
 
         if codename != di_codename:
             distributions_used.append(di_codename)
-            distributions["di_codename"] = {
+            distributions[di_codename] = {
                 "Architectures": "{ARCHES}",
                 "Components": "{mirror_components}",
                 "UDebComponents": "main",
@@ -71,7 +71,7 @@ class ToolMirrorReprepro(ToolShell):
                 "Method": "{debian_mirror}",
                 "VerifyRelease": "{verify_release_keys}",
             },
-            "default-security": {
+            "default-security-legacy": {
                 "Suite": "*/updates",
                 "Architectures": "{ARCHES}",
                 "UDebComponents": "",
@@ -79,7 +79,7 @@ class ToolMirrorReprepro(ToolShell):
                 "FilterList": "deinstall package-list",
                 "VerifyRelease": "{verify_release_keys}",
             },
-            "default-base-security": {
+            "default-base-security-legacy": {
                 "Suite": "*/updates",
                 "Architectures": "{ARCHES}",
                 "UDebComponents": "",
@@ -87,6 +87,22 @@ class ToolMirrorReprepro(ToolShell):
                 "FilterFormula": "priority (== required) | priority (== important) | priority (== standard)",
                 "VerifyRelease": "{verify_release_keys}",
             },
+            "default-security": {
+                "Suite": "{CODENAME}-security",
+                "Architectures": "{ARCHES}",
+                "UDebComponents": "",
+                "Method": "{security_mirror}",
+                "FilterList": "deinstall package-list",
+                "VerifyRelease": "{verify_release_keys}",
+            },
+            "default-base-security": {
+                "Suite": "{CODENAME}-security",
+                "Architectures": "{ARCHES}",
+                "UDebComponents": "",
+                "Method": "{security_mirror}",
+                "FilterFormula": "priority (== required) | priority (== important) | priority (== standard)",
+                "VerifyRelease": "{verify_release_keys}",
+            },
             "default-updates": {
                 "Suite": "{CODENAME}-updates",
                 "Architectures": "{ARCHES}",
@@ -167,8 +183,12 @@ class ToolMirrorReprepro(ToolShell):
             # invoke reprepro's "magic delete" rule.
             updates_used.append("-")
         if self.env.get("security_mirror"):
-            updates_used.append("default-base-security")
-            updates_used.append("default-security")
+            if codename == "buster" or codename == "stretch" or codename == "jessie":
+                updates_used.append("default-base-security-legacy")
+                updates_used.append("default-security-legacy")
+            else:
+                updates_used.append("default-base-security")
+                updates_used.append("default-security")
         if self.env.get("debian_mirror_extra"):
             updates_used.append("default-extra")
             if self.env.get("debian_mirror_extra_dist"):
